# kspconfig-python

 * loadl(list) : 줄 list를 받아 dict를 출력한다
 * loads(str) : 엔터로 묶인 줄 뭉치를 받아 dict를 출력한다
 * dumpl(dict): 위의 출력을 받아 예쁘게 들여써진 줄 list를 출력한다
 * dumps(dict) : 위의 출력을 받아 예쁘게 들여써진 엔터로 묶인 줄 뭉치를 출력한다
 * \_rdump(dict) : 위의 출력을 받아 들여써지지 않은 줄 list를 출력한다
